@@ -11,12 +11,14 @@
 #undef HAVE_SHADOW
 #undef HAVE_CRYPT
 #undef HAVE_LIBXINERAMA
+#undef HAVE_LIBXDMCP
 #undef HAVE_SETENV
 #undef HAVE_UNSETENV
 #undef HAVE_CLEARENV
 #undef EXPANDED_DATADIR
 #undef EXPANDED_PIXMAPDIR
 #undef EXPANDED_BINDIR
+#undef EXPANDED_SBINDIR
 #undef EXPANDED_GDMCONFIGDIR
 #undef EXPANDED_LOCALEDIR
 #undef EXPANDED_AUTHDIR
