@@ -20,7 +20,9 @@
  * support other XAuth types and possibly DECnet... */
 
 #include <config.h>
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <sys/types.h>
+#include <unistd.h>
 #include <sys/stat.h>
 #include <netdb.h> 
 #include <netinet/in.h>
@@ -137,7 +139,7 @@ gdm_auth_secure_display (GdmDisplay *d)
 	    d->authfile = g_strconcat (GdmUserAuthFB, "/.gdmXXXXXX", NULL);
 
 	    umask (077);
-	    authfd = mkstemp (d->authfile);
+	    authfd = g_mkstemp (d->authfile);
 	    umask (022);
 
 	    if (authfd == -1) {
@@ -310,7 +312,7 @@ gdm_auth_secure_display (GdmDisplay *d)
     fclose (af);
     if (af_gdm != NULL)
 	    fclose (af_gdm);
-    ve_setenv ("XAUTHORITY", d->authfile, TRUE);
+    gnome_setenv ("XAUTHORITY", d->authfile, TRUE);
 
     if (GdmDebug)
 	    gdm_debug ("gdm_auth_secure_display: Setting up access for %s - %d entries", 
@@ -361,7 +363,7 @@ gdm_auth_user_add (GdmDisplay *d, uid_t user, const char *homedir)
 	/* No go. Let's create a fallback file in GdmUserAuthFB (/tmp) */
 	d->authfb = TRUE;
 	d->userauth = g_strconcat (GdmUserAuthFB, "/.gdmXXXXXX", NULL);
-	authfd = mkstemp (d->userauth);
+	authfd = g_mkstemp (d->userauth);
 
 	if (authfd == -1) {
 	    gdm_error (_("gdm_auth_user_add: Could not open cookie file %s"), d->userauth);
@@ -443,7 +445,7 @@ void
 gdm_auth_user_remove (GdmDisplay *d, uid_t user)
 {
     FILE *af;
-    const gchar *authfile;
+    gchar *authfile;
     gchar *authdir;
 
     if (!d || !d->userauth)
@@ -460,22 +462,24 @@ gdm_auth_user_remove (GdmDisplay *d, uid_t user)
 	return;
     }
 
-    authfile = g_basename (d->userauth);
-    authdir = g_dirname (d->userauth);
+    authfile = g_path_get_basename (d->userauth);
+    authdir = g_path_get_dirname (d->userauth);
 
     /* Now, the cookie file could be owned by a malicious user who
      * decided to concatenate something like his entire MP3 collection
      * to it. So we better play it safe... */
 
-    if (! gdm_file_check ("gdm_auth_user_remove", user, authdir, authfile, 
-			  TRUE, GdmUserMaxFile, GdmRelaxPerms)) {
+    if ( ! gdm_file_check ("gdm_auth_user_remove", user, authdir, authfile, 
+			   TRUE, GdmUserMaxFile, GdmRelaxPerms)) {
 	    g_free (authdir);
+	    g_free (authfile);
 	    gdm_error (_("gdm_auth_user_remove: Ignoring suspiciously looking cookie file %s"), d->userauth);
 
 	    return; 
     }
 
     g_free (authdir);
+    g_free (authfile);
 
     /* Lock user's cookie jar and open it for writing */
     if (XauLockAuth (d->userauth, 3, 3, 0) != LOCK_SUCCESS)
