@@ -192,7 +192,6 @@ enum {
 #define GDM_KEY_EXCLUDE "greeter/Exclude=bin,daemon,adm,lp,sync,shutdown,halt,mail,news,uucp,operator,nobody,gdm,postgres,pvm"
 #define GDM_KEY_FACE "greeter/DefaultFace=" EXPANDED_PIXMAPDIR "nobody.png"
 #define GDM_KEY_FACEDIR "greeter/GlobalFaceDir=" EXPANDED_DATADIR "/faces/"
-#define GDM_KEY_FONT "greeter/Font=-adobe-helvetica-bold-r-normal-*-*-180-*-*-*-*-*-*"
 #define GDM_KEY_ICON "greeter/Icon=" EXPANDED_PIXMAPDIR "/gdm.xpm"
 #define GDM_KEY_LOCALE "greeter/DefaultLocale=english"
 #define GDM_KEY_LOCFILE "greeter/LocaleFile=" EXPANDED_LOCALEDIR "/locale.alias"
@@ -372,25 +371,22 @@ enum {
 	GDM_XDMCP_LAST_OPCODE /*just a marker, not an opcode */
 };
 
-typedef gboolean (*GSignalFunc) (gint8		signal,
+typedef gboolean (*GDMSignalFunc) (gint8	signal,
 				 gpointer	data);
-guint	g_signal_add		(gint8		signal,
-				 GSignalFunc	function,
+guint	gdm_signal_add		(gint8		signal,
+				 GDMSignalFunc	function,
 				 gpointer    	data);
-guint   g_signal_add_full       (gint           priority,
+guint   gdm_signal_add_full     (gint           priority,
 				 gint8          signal,
-				 GSignalFunc    function,
+				 GDMSignalFunc  function,
 				 gpointer       data,
 				 GDestroyNotify destroy);
-void    g_signal_notify         (gint8          signal);
+void    gdm_signal_notify       (gint8          signal);
 
 /* If id == NULL, then get the first X server */
 GdmXServer *	gdm_find_x_server	(const char *id);
 
 
-void gdm_run (void);
-void gdm_quit (void);
-
 /* primitive protocol for controlling the daemon from slave
  * or gdmconfig or whatnot */
 
