@@ -55,10 +55,11 @@
  */
 
 #include <config.h> 
-#include <gnome.h>
+#include <libgnome/libgnome.h>
 
 #ifdef HAVE_LIBXDMCP
 #include <stdio.h>
+#include <unistd.h>
 #include <time.h>
 #include <stdlib.h>
 #include <syslog.h>
@@ -278,6 +279,8 @@ gdm_xdmcp_run (void)
 	GIOChannel *xdmcpchan;
 
 	xdmcpchan = g_io_channel_unix_new (gdm_xdmcpfd);
+	g_io_channel_set_buffered (xdmcpchan, FALSE);
+
 	xdmcp_source = g_io_add_watch_full
 		(xdmcpchan, G_PRIORITY_DEFAULT,
 		 G_IO_IN|G_IO_PRI|G_IO_ERR|G_IO_HUP|G_IO_NVAL,
